@@ -6,7 +6,7 @@ use 5.010;
 use Carp;
 
 use Scalar::Util qw/blessed/;
-use Moo::Lax;
+use Moo;
 
 has 'data' => (is => 'ro',
                writer => '_set_data',
